package db

import (
	"flag"
	"fmt"
	_ "github.com/go-sql-driver/mysql"
	"github.com/go-xorm/xorm"
	"lapp_-wy/conf"
	"lapp_-wy/utils"
	"lapp_-wy/web/middleware/glog"
	"log"
	"path/filepath"
	"testing"
)

func TestDb(t *testing.T) {
	var (
		engine *xorm.Engine
		err    error
	)

	c := conf.MasterDbConfig

	driveSource := fmt.Sprintf("%s:%s@tcp(%s:%d)/%s?charset=utf8",
		c.User, c.Pwd, c.Host, c.Port, c.DbName)
	fmt.Print(driveSource)
	if engine, err = xorm.NewEngine(conf.DriverName, driveSource); err != nil {
		t.Error(err)
		return
	}
	//开启sql，debug
	engine.ShowSQL(true)
	if err = engine.Ping(); err != nil {
		log.Println("数据库连接失败:", driveSource, err.Error())
		return
	} else {
		log.Println("数据库连接成功：", driveSource)
	}
}

//测试日志
func TestLog(t *testing.T) {
	baseDir := ""
	flag.StringVar(&baseDir, "dir", "log", "running in a directory")
	flag.Parse()

	defer glog.Flush()
	fmt.Println(baseDir)
	baseDir = utils.EnsureDir(baseDir)
	fmt.Println(baseDir)
	pathLogDir := filepath.Join(baseDir,"glog")
	fmt.Println(pathLogDir)
	glog.DefaultInit(true, pathLogDir)

	glog.Infoln("启动日志","InitDB return success")
	glog.InfoExtf("订单信息日志", "记录的信息:%v",100)
	glog.InfoExtf("订单信息日志", "记录的信息:%v",500)
	glog.InfoExtf("测试信息日志", "记录的信息:%v",300)
	glog.ErrorExt("订单错误日志", "错误原因是哈哈哈")
}

func TestTime(t *testing.T){
	enddate := "2020-01-01"
	begtime,_ := utils.TimeParseyyyyMMdd(enddate)
	Lengthdate := 12
	endTime := begtime.AddDate(0, utils.ValueToInt(Lengthdate, 0), 0)
	Enddate := utils.TimeFormat(endTime, "yyyy-MM-dd")
	t.Log(Enddate)
}
