package controllers

import (
	"lapp_-wy/utils"
	"lapp_-wy/web/middleware/jwts"
	"lapp_-wy/web/models"
	"lapp_-wy/web/supports"
	"github.com/kataras/iris"
	"time"
)

func GetAssettabList(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	logs := new(models.LeitServerLog)
	logs.File = "/controllers/Assettab_controller.go"
	logs.Level = "info"
	logs.Function = "GetAssettabList"
	logs.Message = "资产列表查看"
	logs.Operator = user.Userid
	logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	logs.InsertRecord()
	var data models.Assettab
	var err error
	var pageSize = 10
	var pageIndex = 1

	if size := ctx.URLParam("pageSize"); size != "" {
		pageSize = utils.ValueToInt(size, 0)
	}

	if index := ctx.URLParam("pageIndex"); index != "" {
		pageIndex = utils.ValueToInt(index, 0)
	}
	data.Cid = user.Pid
	data.Descr = ctx.URLParam("descr")
	result, count, err := data.GetPage(pageSize, pageIndex)
	if err != nil {
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	res := make(map[string]interface{})
	res["data"] = result
	res["count"] = count
	res["pageIndex"] = pageIndex
	res["pageSize"] = pageSize
	supports.Ok(ctx, supports.OptionSuccess, res)
}

func GetAssettab(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	var me models.Assettab
	me.Cid = user.Pid
	me.Assetid = ctx.URLParam("assetid")
	result, err := me.SelectOne()
	if err !=nil{
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	supports.Ok(ctx, supports.OptionSuccess, result)
}

func InsertAssettab(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	logs := new(models.LeitServerLog)
	logs.File = "/controllers/Assettab_controller.go"
	logs.Level = "info"
	logs.Function = "InsertAssettab"
	logs.Message = "添加资产"
	logs.Operator = user.Userid
	logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	logs.InsertRecord()
	data := new(models.Assettab)
	data.Lastmodifyby = user.Userid
	data.Createtime = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	data.Lastmodifytime = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	if err := ctx.ReadJSON(data); err != nil {
		logs := new(models.LeitServerLog)
		logs.File = "/controllers/Assettab_controller.go"
		logs.Level = "debug"
		logs.Function = "InsertAssettab"
		logs.Message = error.Error(err)
		logs.Operator = user.Userid
		logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
		logs.InsertRecord()
		supports.Error(ctx, iris.StatusBadRequest, "json解析错误", nil)
		return
	}
	data.Cid = user.Pid
	err := data.Add()
	if err != nil{
		supports.Error(ctx, iris.StatusBadRequest,"添加失败！", nil)
		return
	}
	supports.Ok(ctx, supports.OptionSuccess, data)
}

func UpdateAssettab(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	logs := new(models.LeitServerLog)
	logs.File = "/controllers/Assettab_controller.go"
	logs.Level = "info"
	logs.Function = "UpdateAssettab"
	logs.Message = "更新资产"
	logs.Operator = user.Userid
	logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	logs.InsertRecord()
	data := new(models.Assettab)
	if err := ctx.ReadJSON(data); err != nil {
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	data.Lastmodifyby = user.Userid
	res:= data.Update()
	if !res{
		supports.Error(ctx, iris.StatusBadRequest, "更新失败", nil)
		return
	}

	supports.Ok(ctx, "修改成功", "")
}

func DeleteAssettab(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	logs := new(models.LeitServerLog)
	logs.File = "/controllers/Assettab_controller.go"
	logs.Level = "info"
	logs.Function = "DeleteAssettab"
	logs.Message = "删除资产"
	logs.Operator = user.Userid
	logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	logs.InsertRecord()
	me:=new(models.Assettab)
	me.Cid = user.Pid
	me.Assetid = ctx.URLParam("assetid")
	res := me.Del()
	if !res {
		supports.Error(ctx, iris.StatusBadRequest, "删除失败", nil)
		return
	}
	supports.Ok(ctx, "删除成功", "")
}
