package controllers


import (
	"lapp_-wy/utils"
	"lapp_-wy/web/middleware/jwts"
	"lapp_-wy/web/models"
	"lapp_-wy/web/supports"
	"github.com/kataras/iris"
	"time"
)

func GetWfApprovalmodelList(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	log := new(models.LeitServerLog)
	log.File = "/controllers/WfApprovalmodel_controller.go"
	log.Level = "info"
	log.Function = "GetWfApprovalmodelList"
	log.Message = "模板查看"
	log.Operator = user.Userid
	log.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	log.InsertRecord()
	var data models.WfApprovalmodel
	var err error
	var pageSize = 10
	var pageIndex = 1

	if size := ctx.URLParam("pageSize"); size != "" {
		pageSize = utils.ValueToInt(size, 0)
	}

	if index := ctx.URLParam("pageIndex"); index != "" {
		pageIndex = utils.ValueToInt(index, 0)
	}
	data.Descr = ctx.URLParam("descr")
	result, count, err := data.GetPage(pageSize, pageIndex)
	if err != nil {
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	res := make(map[string]interface{})
	res["data"] = result
	res["count"] = count
	res["pageIndex"] = pageIndex
	res["pageSize"] = pageSize
	supports.Ok(ctx, supports.OptionSuccess, res)
}

func GetWfApprovalmodel(ctx iris.Context) {
	var me models.WfApprovalmodel
	approvalmodelid, _ := ctx.URLParamInt("approvalmodelid")
	me.Approvalmodelid = approvalmodelid
	result, err := me.SelectOne()
	if err !=nil{
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	result.Clipped()
	supports.Ok(ctx, supports.OptionSuccess, result)
}

func InsertWfApprovalmodel(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	log := new(models.LeitServerLog)
	log.File = "/controllers/workline_controller.go"
	log.Level = "info"
	log.Function = "InsertWfApprovalmodel"
	log.Message = "添加模板"
	log.Operator = user.Userid
	log.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	log.InsertRecord()
	data := new(models.WfApprovalmodel)
	data.Lastuser = user.Userid
	data.Credatuz = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	data.Lastmodif = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	if err := ctx.ReadJSON(data); err != nil {
		log := new(models.LeitServerLog)
		log.File = "/controllers/WfApprovalmodel_controller.go"
		log.Level = "debug"
		log.Function = "InsertWfApprovalmodel"
		log.Message = error.Error(err)
		log.Operator = user.Userid
		log.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
		log.InsertRecord()
		supports.Error(ctx, iris.StatusBadRequest, "json解析错误", nil)
		return
	}
	err := data.Add()
	if err != nil{
		supports.Error(ctx, iris.StatusBadRequest,"添加失败！", nil)
		return
	}
	supports.Ok(ctx, supports.OptionSuccess, data)
}

func UpdateWfApprovalmodel(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	log := new(models.LeitServerLog)
	log.File = "/controllers/WfApprovalmodel_controller.go"
	log.Level = "info"
	log.Function = "UpdateWfApprovalmodel"
	log.Message = "模板定义"
	log.Operator = user.Userid
	log.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	log.InsertRecord()
	data := new(models.WfApprovalmodel)
	if err := ctx.ReadJSON(data); err != nil {
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	data.Lastuser = user.Userid
	res:= data.Update()
	if !res{
		supports.Error(ctx, iris.StatusBadRequest, "更新失败", nil)
		return
	}

	supports.Ok(ctx, "修改成功", "")
}

func DeleteWfApprovalmodel(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	log := new(models.LeitServerLog)
	log.File = "/controllers/WfApprovalmodel_controller.go"
	log.Level = "info"
	log.Function = "DeleteWfApprovalmodel"
	log.Message = "删除模板"
	log.Operator = user.Userid
	log.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	log.InsertRecord()
	me:=new(models.WfApprovalmodel)
	approvalmodelid, _ := ctx.URLParamInt("approvalmodelid")
	me.Approvalmodelid = approvalmodelid
	res := me.Del()
	if !res {
		supports.Error(ctx, iris.StatusBadRequest, "删除失败", nil)
		return
	}
	supports.Ok(ctx, "删除成功", "")
}

func AllWfApprovalmodel(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	log := new(models.LeitServerLog)
	log.File = "/controllers/WfApprovalmodel_controller.go"
	log.Level = "info"
	log.Function = "AllWfApprovalmodel"
	log.Message = "查询模板"
	log.Operator = user.Userid
	log.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	log.InsertRecord()
	me:=new(models.WfApprovalmodel)
	data,err := me.AllModels()
	if err !=nil {
		supports.Error(ctx, iris.StatusBadRequest, "失败", nil)
		return
	}
	supports.Ok(ctx, "成功", data)
}