package routes

import (
	"github.com/kataras/iris"
	"lapp_-wy/web/controllers"
	"lapp_-wy/web/middleware"
	"lapp_-wy/web/middleware/cors"
)

// 所有的路由
func Hub(app *iris.Application) {

	/* 定义路由 */
	main := app.Party("/", cors.Mycors()).AllowMethods(iris.MethodOptions)
	//中间件，验证token和权限路径
	main.Use(middleware.Recover)
	main.Use(middleware.ServeHTTP)

	home := main.Party("/")
	home.Get("/sysMenu", controllers.DynamicMenu) // 获取动态菜单

	// 用户API模块
	user := main.Party("/user")
	user.Post("/login", controllers.Login)            //登录
	user.Get("/courts", controllers.CourtsTable)      //项目列表
	user.Get("/getuserinfo", controllers.GetUserInfo) // 返回用户信息
	//个人中心
	user.Get("/profile", controllers.GetSysUserProfile)  //获取当前登录用户
	user.Get("/getimg", controllers.GetImg)              //重定向获取图片
	user.Post("/avatar", controllers.InsetSysUserAvatar) //上传图片
	user.Put("/pwd", controllers.SysUserUpdatePwd)       //更新密码

	//// 权限API模块
	admin := main.Party("/admin")
	{
		// 用户管理
		users := admin.Party("/users")
		users.Get("/userlist", controllers.GetSysUserList)                  // 用户列表
		users.Get("/user/{userId:string}", controllers.GetSysUser)          //获取用户
		users.Get("/urole", controllers.GetSysUserInit)                     //获取用户角色
		users.Get("/alluser", controllers.GetAllUsers)                      //获取所有用户名
		users.Post("/adduser", controllers.InsertSysUser)                   //添加用户
		users.Put("/upuser", controllers.UpdateSysUser)                     //更新用户
		users.Delete("/deluser/{userId:string}", controllers.DeleteSysUser) //删除用户

		//角色管理
		role := admin.Party("/role")
		role.Get("/rolelist", controllers.GetRoleList)                  // 角色报表
		role.Get("/rolebyid", controllers.GetRole)                      // 查询角色
		role.Post("/addrole", controllers.InsertRole)                   // 创建角色
		role.Put("/uprole", controllers.UpdateRole)                     // 更新角色
		role.Delete("/delrole/{roleId:string}", controllers.DeleteRole) // 删除角色

		//菜单管理
		menu := admin.Party("/menu")
		menu.Get("/menulist", controllers.GetMenuList)                                  //菜单列表
		menu.Get("/menubyid", controllers.GetMenu)                                      //by id查询
		menu.Post("/addmenu", controllers.InsertMenu)                                   //添加菜单
		menu.Put("/upmenu", controllers.UpdateMenu)                                     //更新菜单
		menu.Delete("/delmenu/{id:int}", controllers.DeleteMenu)                        //删除菜单
		menu.Get("/menuids", controllers.GetMenuIDS)                                    //通过ids查询菜单
		menu.Get("/menuTreeselect", controllers.GetMenuTreeelect)                       //获取菜单列表
		menu.Get("/roleMenuTreeselect/{roleId:int}", controllers.GetMenuTreeRoleselect) //获取菜单

		// 日志管理
		logs := admin.Party("/logs")
		logs.Get("/loglist", controllers.Loglist)

		// 翻译列表
		tabnames := admin.Party("/tabnames")
		tabnames.Post("/addinfo", controllers.TabInfo)
		tabnames.Get("/listpage", controllers.TabDataListPage)
		tabnames.Get("/list", controllers.TabDataList)
		tabnames.Get("/download", controllers.Download)
		tabnames.Delete("/del", controllers.DeleteTab)

		// 标准定义
		stdeftab := admin.Party("/stdeftab")
		stdeftab.Get("/listpage", controllers.GetStdeftabList)
		stdeftab.Get("/selectinfo", controllers.GetStdeftab)
		stdeftab.Post("/addinfo", controllers.InsertStdeftab)
		stdeftab.Delete("/del", controllers.DeleteStdeftab)
		stdeftab.Put("/upinfo", controllers.UpdateStdeftab)
		stdeftab.Get("/selectarr", controllers.SelectStdeftabArr)
		stdeftab.Get("/selectall", controllers.SelectStdeftabAll)

		// 订单流水号
		snrtab := admin.Party("/snrtab")
		snrtab.Get("/listpage", controllers.GetSnrtabList)
		snrtab.Get("/selectinfo", controllers.GetSnrtab)
		snrtab.Post("/addinfo", controllers.InsertSnrtab)
		snrtab.Delete("/del", controllers.DeleteSnrtab)
		snrtab.Put("/upinfo", controllers.UpdateSnrtab)

		// 导入表
		scripttab := admin.Party("/scripttab")
		scripttab.Get("/listpage", controllers.GetScripttabList)
		scripttab.Get("/selectinfo", controllers.GetScripttab)
		scripttab.Post("/addinfo", controllers.InsertScripttab)
		scripttab.Delete("/del", controllers.DeleteScripttab)
		scripttab.Put("/upinfo", controllers.UpdateScripttab)
		scripttab.Post("/upexcel", controllers.UpExcelScripttab)
		scripttab.Get("/selectarr", controllers.SelectArrScripttab)

		// 项目
		courttab := admin.Party("/courttab")
		courttab.Get("/listpage", controllers.GetCourttabList)
		courttab.Get("/selectinfo", controllers.GetCourttab)
		courttab.Put("/upinfo", controllers.UpdateCourttab)
		courttab.Post("/addinfo", controllers.InsertCourttab)
		courttab.Delete("/del", controllers.DeleteCourttab)

		// 楼栋定义
		buildingtab := admin.Party("/buildingtab")
		buildingtab.Get("/listpage", controllers.GetBuildingtabList)
		buildingtab.Get("/selectinfo", controllers.GetBuildingtab)
		buildingtab.Get("/selectall", controllers.GetBuildingtabAll)
		buildingtab.Put("/upinfo", controllers.UpdateBuildingtab)
		buildingtab.Post("/addinfo", controllers.InsertBuildingtab)
		buildingtab.Delete("/del", controllers.DeleteBuildingtab)

		// 房间定义
		propertytab := admin.Party("/propertytab")
		propertytab.Get("/listpage", controllers.GetPropertytabList)
		propertytab.Get("/selectinfo", controllers.GetPropertytab)
		propertytab.Get("/searchinfo", controllers.SearchPropertytab)
		propertytab.Put("/upinfo", controllers.UpdatePropertytab)
		propertytab.Post("/addinfo", controllers.InsertPropertytab)
		propertytab.Delete("/del", controllers.DeletePropertytab)

		// 资产类型
		propertytypetab := admin.Party("/propertytypetab")
		propertytypetab.Get("/listpage", controllers.GetPropertytypetabList)
		propertytypetab.Get("/selectinfo", controllers.GetPropertytypetab)
		propertytypetab.Put("/upinfo", controllers.UpdatePropertytypetab)
		propertytypetab.Post("/addinfo", controllers.InsertPropertytypetab)
		propertytypetab.Delete("/del", controllers.DeletePropertytypetab)

		//电梯卡列表
		accesscardtab := admin.Party("/accesscardtab")
		accesscardtab.Get("/listpage", controllers.GetAccesscardtabList)
		accesscardtab.Get("/selectinfo", controllers.GetAccesscardtab)
		accesscardtab.Get("/searchinfo", controllers.SearchAccesscardtab)
		accesscardtab.Put("/upinfo", controllers.UpdateAccesscardtab)
		accesscardtab.Post("/addinfo", controllers.InsertAccesscardtab)
		accesscardtab.Delete("/del", controllers.DeleteAccesscardtab)

		// 车位
		carporttab := admin.Party("/carporttab")
		carporttab.Get("/listpage", controllers.GetCarporttabList)
		carporttab.Get("/selectinfo", controllers.GetCarporttab)
		carporttab.Get("/searchinfo", controllers.SearchCarporttab)
		carporttab.Put("/upinfo", controllers.UpdateCarporttab)
		carporttab.Post("/addinfo", controllers.InsertCarporttab)
		carporttab.Delete("/del", controllers.DeleteCarporttab)

		//收费记录表
		chargetab := admin.Party("/chargetab")
		chargetab.Get("/listpage", controllers.GetChargeArrearageData)
		chargetab.Get("/countmoney", controllers.GetChargeComputeMoney)
		chargetab.Get("/datapage", controllers.GetChargetabListPage)
		chargetab.Get("/selectinfo", controllers.GetChargetab)
		chargetab.Get("/totalyear", controllers.GetChargetabStatisticByYear)
		chargetab.Get("/totalbuilding", controllers.GetChargetabByBuilding)
		chargetab.Get("/readexcel", controllers.GetChargetabReadExcel)
		chargetab.Get("/readbuildexcel", controllers.GetChargetabReadBuildingExcel)
		chargetab.Get("/readyearexcel", controllers.GetChargetabReadYearExcel)
		chargetab.Get("/readdataexcel", controllers.ExportChargeArrearageExcel)
		chargetab.Delete("/del", controllers.DelChargetab)
		chargetab.Get("/recordlist", controllers.GetRecordLogList)
		chargetab.Get("/statistic", controllers.GetChargeStatisticData)
		chargetab.Get("/type/list", controllers.GetChargeWayListData)
		chargetab.Get("/readtypeexcel", controllers.ExportChargeWayDataListExcel)

		// 固定资产
		assettab := admin.Party("/assettab")
		assettab.Get("/listpage", controllers.GetAssettabList)
		assettab.Get("/selectinfo", controllers.GetAssettab)
		assettab.Put("/upinfo", controllers.UpdateAssettab)
		assettab.Post("/addinfo", controllers.InsertAssettab)
		assettab.Delete("/del", controllers.DeleteAssettab)

		//合同
		contracttab := admin.Party("/contracttab")
		contracttab.Post("/addinfo", controllers.InsertContracttab)
		contracttab.Post("/toexcel", controllers.ExcelContracttab) //临时更新

		//模板定义
		wf_approvalmodel := admin.Party("/wf_approvalmodel")
		wf_approvalmodel.Get("/listpage", controllers.GetWfApprovalmodelList)
		wf_approvalmodel.Get("/selectinfo", controllers.GetWfApprovalmodel)
		wf_approvalmodel.Put("/upinfo", controllers.UpdateWfApprovalmodel)
		wf_approvalmodel.Post("/addinfo", controllers.InsertWfApprovalmodel)
		wf_approvalmodel.Delete("/del", controllers.DeleteWfApprovalmodel)
		wf_approvalmodel.Get("/allmodels", controllers.AllWfApprovalmodel)

		//申报定义
		wf_approvalrequest := admin.Party("/wf_approvalrequest")
		wf_approvalrequest.Get("/listpage", controllers.GetWfApprovalrequestList)
		wf_approvalrequest.Get("/selectinfo", controllers.GetWfApprovalrequest)
		wf_approvalrequest.Put("/upinfo", controllers.UpdateWfApprovalrequest)
		wf_approvalrequest.Post("/addinfo", controllers.InsertWfApprovalrequest)
		wf_approvalrequest.Delete("/del", controllers.DeleteWfApprovalrequest)
		wf_approvalrequest.Put("/updetail", controllers.UpdateWfApprovalrequestDetail)
		wf_approvalrequest.Post("/adddetail", controllers.InsertWfApprovalrequestDetail)
		wf_approvalrequest.Delete("/deldetail", controllers.DeleteWfApprovalrequestDetail)
		wf_approvalrequest.Get("/selectdetail", controllers.GetWfApprovalrequestDetail)

		//审批
		wf_approvalrequest_step := admin.Party("/wf_approvalrequest_step")
		wf_approvalrequest_step.Get("/listpage", controllers.GetWfApprovalrequestStepList)
		wf_approvalrequest_step.Get("/datapage", controllers.GetWfApprovalrequestStepData)
		wf_approvalrequest_step.Get("/auditinfo", controllers.GetWfApprovalrequestStepAuditInfo)
		wf_approvalrequest_step.Get("/treeinfo", controllers.GetWfApprovalrequestStepTreeInfo)

		//公司信息
		company := admin.Party("/company")
		company.Get("/listpage", controllers.GetCompanyList)
		company.Get("/selectinfo", controllers.GetCompany)
		company.Put("/upinfo", controllers.UpdateCompany)
		company.Post("/addinfo", controllers.InsertCompany)
		company.Delete("/del", controllers.DeleteCompany)

		//问题分类
		subject_category := admin.Party("/subject_category")
		subject_category.Get("/listpage", controllers.GetSubjectCategoryList)
		subject_category.Get("/selectinfo", controllers.GetSubjectCategory)
		subject_category.Get("/selectarr", controllers.AllSubjectCategory)
		subject_category.Put("/upinfo", controllers.UpdateSubjectCategory)
		subject_category.Post("/addinfo", controllers.InsertSubjectCategory)
		subject_category.Delete("/del", controllers.DeleteSubjectCategory)

		//问题
		subject := admin.Party("/subject")
		subject.Get("/listpage", controllers.GetSubjectList)
		subject.Post("/media", controllers.UploadSubject)
		subject.Get("/selectinfo", controllers.GetSubject)
		subject.Put("/upinfo", controllers.UpdateSubject)
		subject.Post("/addinfo", controllers.InsertSubject)
		subject.Delete("/del", controllers.DeleteSubject)
		subject.Get("/selectarr", controllers.SubjectArr)

		//调查问卷
		c_surveysheet := admin.Party("/c_surveysheet")
		c_surveysheet.Get("/listpage", controllers.GetCSurveysheetList)
		c_surveysheet.Get("/selectinfo", controllers.GetCSurveysheet)
		c_surveysheet.Put("/upinfo", controllers.UpdateCSurveysheet)
		c_surveysheet.Post("/addinfo", controllers.InsertCSurveysheet)
		c_surveysheet.Delete("/del", controllers.DeleteCSurveysheet)

		//用户答题
		c_surveysheet_result := admin.Party("/c_surveysheet_result")
		c_surveysheet_result.Post("/addinfo", controllers.InsertCSurveysheetResult)
		c_surveysheet_result.Get("/total", controllers.TotalCSurveysheetResult)
		c_surveysheet_result.Get("/totalmultiple", controllers.TotalMultipleCSurveysheetResult)
		c_surveysheet_result.Get("/selectarr", controllers.SelectArrCSurveysheet)

		//添加其他费用
		otherchargetab := admin.Party("/otherchargetab")
		otherchargetab.Get("/listpage", controllers.GetOtherchargetabList)
		otherchargetab.Get("/selectinfo", controllers.GetOtherchargetab)
		otherchargetab.Post("/addinfo", controllers.InsertOtherchargetab)

	}

}
